summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/kexidb')
-rw-r--r--kexi/kexidb/connection.h2
-rw-r--r--kexi/kexidb/expression.cpp2
-rw-r--r--kexi/kexidb/fieldlist.h2
-rw-r--r--kexi/kexidb/indexschema.cpp14
-rw-r--r--kexi/kexidb/indexschema.h4
-rw-r--r--kexi/kexidb/lookupfieldschema.cpp4
-rw-r--r--kexi/kexidb/lookupfieldschema.h4
-rw-r--r--kexi/kexidb/parser/sqlparser.y2
-rw-r--r--kexi/kexidb/queryschema.h4
-rw-r--r--kexi/kexidb/utils.cpp8
-rw-r--r--kexi/kexidb/utils.h10
11 files changed, 28 insertions, 28 deletions
diff --git a/kexi/kexidb/connection.h b/kexi/kexidb/connection.h
index 79bd38406..3d4eb82cb 100644
--- a/kexi/kexidb/connection.h
+++ b/kexi/kexidb/connection.h
@@ -232,7 +232,7 @@ class KEXI_DB_EXPORT Connection : public TQObject, public KexiDB::Object
Transaction beginTransaction();
/*! \todo for nested transactions:
- Tansaction* beginTransaction(transaction *tqparent_transaction);
+ Tansaction* beginTransaction(transaction *parent_transaction);
*/
/*! Commits transaction \a trans.
If there is not \a trans argument passed, and there is default transaction
diff --git a/kexi/kexidb/expression.cpp b/kexi/kexidb/expression.cpp
index 0428fdcfd..ffa45c9b7 100644
--- a/kexi/kexidb/expression.cpp
+++ b/kexi/kexidb/expression.cpp
@@ -246,7 +246,7 @@ TQString UnaryExpr::debugString()
TQString UnaryExpr::toString(QuerySchemaParameterValueListIterator* params)
{
- if (m_token=='(') //tqparentheses (special case)
+ if (m_token=='(') //parentheses (special case)
return "(" + (m_arg ? m_arg->toString(params) : "<NULL>") + ")";
if (m_token < 255 && isprint(m_token))
return tokenToDebugString() + (m_arg ? m_arg->toString(params) : "<NULL>");
diff --git a/kexi/kexidb/fieldlist.h b/kexi/kexidb/fieldlist.h
index c5f28d5b3..f77dba2b4 100644
--- a/kexi/kexidb/fieldlist.h
+++ b/kexi/kexidb/fieldlist.h
@@ -135,7 +135,7 @@ class KEXI_DB_EXPORT FieldList
/*! \return a string that is a result of all field names concatenated
and with \a separator. This is usable e.g. as argument like "field1,field2"
for "INSERT INTO (xxx) ..". The result of this method is effectively cached,
- and it is tqinvalidated when set of fields changes (e.g. using clear()
+ and it is invalidated when set of fields changes (e.g. using clear()
or addField()).
\a tableAlias, if provided is prepended to each field, so the resulting
names will be in form tableAlias.fieldName. This option is used for building
diff --git a/kexi/kexidb/indexschema.cpp b/kexi/kexidb/indexschema.cpp
index c672305a2..4775125b8 100644
--- a/kexi/kexidb/indexschema.cpp
+++ b/kexi/kexidb/indexschema.cpp
@@ -41,11 +41,11 @@ IndexSchema::IndexSchema(TableSchema *tableSchema)
m_master_owned_rels.setAutoDelete(true); //rels at the master-side are owned
}
-IndexSchema::IndexSchema(const IndexSchema& idx, TableSchema& tqparentTable)
+IndexSchema::IndexSchema(const IndexSchema& idx, TableSchema& parentTable)
// : FieldList(static_cast<const FieldList&>(idx))//fields are not owned by IndexSchema object
: FieldList(false)//fields are not owned by IndexSchema object
, SchemaData(static_cast<const SchemaData&>(idx))
- , m_tableSchema(&tqparentTable)
+ , m_tableSchema(&parentTable)
, m_primary( idx.m_primary )
, m_unique( idx.m_unique )
, m_isAutoGenerated( idx.m_isAutoGenerated )
@@ -55,14 +55,14 @@ IndexSchema::IndexSchema(const IndexSchema& idx, TableSchema& tqparentTable)
//deep copy of the fields
for (Field::ListIterator f_it(idx.m_fields); f_it.current(); ++f_it) {
- Field *tqparentTableField = tqparentTable.field( f_it.current()->name() );
- if (!tqparentTableField) {
- KexiDBWarn << "IndexSchema::IndexSchema(const IndexSchema& idx, const TableSchema& tqparentTable): "
- "cannot find field '" << f_it.current()->name() << " in tqparentTable. Empty index will be created!" << endl;
+ Field *parentTableField = parentTable.field( f_it.current()->name() );
+ if (!parentTableField) {
+ KexiDBWarn << "IndexSchema::IndexSchema(const IndexSchema& idx, const TableSchema& parentTable): "
+ "cannot find field '" << f_it.current()->name() << " in parentTable. Empty index will be created!" << endl;
FieldList::clear();
break;
}
- addField( tqparentTableField );
+ addField( parentTableField );
}
//js TODO: copy relationships!
diff --git a/kexi/kexidb/indexschema.h b/kexi/kexidb/indexschema.h
index 60d1d7ac7..12feae04f 100644
--- a/kexi/kexidb/indexschema.h
+++ b/kexi/kexidb/indexschema.h
@@ -56,7 +56,7 @@ class KEXI_DB_EXPORT IndexSchema : public FieldList, public SchemaData
/*! Copy constructor. Copies all attributes from index \a idx, and
fields assigned with it but the fields are taken (by name) from
- \a tqparentTable, not from \a idx itself, so it's possible to copy of index
+ \a parentTable, not from \a idx itself, so it's possible to copy of index
for a copy of table.
To copy an index within the same table it's enough to call:
@@ -65,7 +65,7 @@ class KEXI_DB_EXPORT IndexSchema : public FieldList, public SchemaData
\endcode
@todo All relationships should be also copied
*/
- IndexSchema(const IndexSchema& idx, TableSchema& tqparentTable);
+ IndexSchema(const IndexSchema& idx, TableSchema& parentTable);
/*! Destroys the index. Field objects are not deleted.
All Relationship objects listed in masterRelationships() list
diff --git a/kexi/kexidb/lookupfieldschema.cpp b/kexi/kexidb/lookupfieldschema.cpp
index 66ed43969..62a0665e1 100644
--- a/kexi/kexidb/lookupfieldschema.cpp
+++ b/kexi/kexidb/lookupfieldschema.cpp
@@ -254,12 +254,12 @@ LookupFieldSchema *LookupFieldSchema::loadFromDom(const TQDomElement& lookupEl)
}
/* static */
-void LookupFieldSchema::saveToDom(LookupFieldSchema& lookupSchema, TQDomDocument& doc, TQDomElement& tqparentEl)
+void LookupFieldSchema::saveToDom(LookupFieldSchema& lookupSchema, TQDomDocument& doc, TQDomElement& parentEl)
{
TQDomElement lookupColumnEl, rowSourceEl, rowSourceTypeEl, nameEl;
if (!lookupSchema.rowSource().name().isEmpty()) {
lookupColumnEl = doc.createElement("lookup-column");
- tqparentEl.appendChild( lookupColumnEl );
+ parentEl.appendChild( lookupColumnEl );
rowSourceEl = doc.createElement("row-source");
lookupColumnEl.appendChild( rowSourceEl );
diff --git a/kexi/kexidb/parser/sqlparser.y b/kexi/kexidb/parser/sqlparser.y
index 426dec488..7775885d7 100644
--- a/kexi/kexidb/parser/sqlparser.y
+++ b/kexi/kexidb/parser/sqlparser.y
@@ -1003,7 +1003,7 @@ aExpr9 '/' aExpr8
aExpr9
;
-/* tqparenthesis, unary operators, and terminals precedence */
+/* parenthesis, unary operators, and terminals precedence */
aExpr9:
/* --- unary logical left --- */
'-' aExpr9
diff --git a/kexi/kexidb/queryschema.h b/kexi/kexidb/queryschema.h
index a68acffe7..7c6821d16 100644
--- a/kexi/kexidb/queryschema.h
+++ b/kexi/kexidb/queryschema.h
@@ -357,7 +357,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
/*! Removes \a table schema from this query.
This does not destroy \a table object but only takes it out of the list.
If this table was master for the query, master table information is also
- tqinvalidated. */
+ invalidated. */
void removeTable(TableSchema *table);
/*! \return table with name \a tableName or 0 if this query has no such table. */
@@ -694,7 +694,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
for \a infolist, with "," between each one.
This is usable e.g. as argument like "field1,field2"
for "INSERT INTO (xxx) ..". The result of this method is effectively cached,
- and it is tqinvalidated when set of fields changes (e.g. using clear()
+ and it is invalidated when set of fields changes (e.g. using clear()
or addField()).
This method is similar to FieldList::sqlFieldsList() it just uses
diff --git a/kexi/kexidb/utils.cpp b/kexi/kexidb/utils.cpp
index a44f9c362..36267b1fa 100644
--- a/kexi/kexidb/utils.cpp
+++ b/kexi/kexidb/utils.cpp
@@ -946,22 +946,22 @@ TQVariant KexiDB::loadPropertyValueFromDom( const TQDomNode& node )
return TQVariant();
}
-TQDomElement KexiDB::saveNumberElementToDom(TQDomDocument& doc, TQDomElement& tqparentEl,
+TQDomElement KexiDB::saveNumberElementToDom(TQDomDocument& doc, TQDomElement& parentEl,
const TQString& elementName, int value)
{
TQDomElement el( doc.createElement(elementName) );
- tqparentEl.appendChild( el );
+ parentEl.appendChild( el );
TQDomElement numberEl( doc.createElement("number") );
el.appendChild( numberEl );
numberEl.appendChild( doc.createTextNode( TQString::number(value) ) );
return el;
}
-TQDomElement KexiDB::saveBooleanElementToDom(TQDomDocument& doc, TQDomElement& tqparentEl,
+TQDomElement KexiDB::saveBooleanElementToDom(TQDomDocument& doc, TQDomElement& parentEl,
const TQString& elementName, bool value)
{
TQDomElement el( doc.createElement(elementName) );
- tqparentEl.appendChild( el );
+ parentEl.appendChild( el );
TQDomElement numberEl( doc.createElement("bool") );
el.appendChild( numberEl );
numberEl.appendChild( doc.createTextNode(
diff --git a/kexi/kexidb/utils.h b/kexi/kexidb/utils.h
index fff7a0719..b8ee03b5b 100644
--- a/kexi/kexidb/utils.h
+++ b/kexi/kexidb/utils.h
@@ -350,20 +350,20 @@ namespace KexiDB
KEXI_DB_EXPORT TQString loadStringPropertyValueFromDom( const TQDomNode& node, bool* ok );
/*! Saves integer element for value \a value to \a doc document within tqparent element
- \a tqparentEl. The value will be enclosed in "number" element and "elementName" element.
- Example: saveNumberElementToDom(doc, tqparentEl, "height", 15) will create
+ \a parentEl. The value will be enclosed in "number" element and "elementName" element.
+ Example: saveNumberElementToDom(doc, parentEl, "height", 15) will create
\code
<height><number>15</number></height>
\endcode
\return the reference to element created with tag elementName. */
- KEXI_DB_EXPORT TQDomElement saveNumberElementToDom(TQDomDocument& doc, TQDomElement& tqparentEl,
+ KEXI_DB_EXPORT TQDomElement saveNumberElementToDom(TQDomDocument& doc, TQDomElement& parentEl,
const TQString& elementName, int value);
/*! Saves boolean element for value \a value to \a doc document within tqparent element
- \a tqparentEl. Like saveNumberElementToDom() but creates "bool" tags. True/false values will be
+ \a parentEl. Like saveNumberElementToDom() but creates "bool" tags. True/false values will be
saved as "true"/"false" strings.
\return the reference to element created with tag elementName. */
- KEXI_DB_EXPORT TQDomElement saveBooleanElementToDom(TQDomDocument& doc, TQDomElement& tqparentEl,
+ KEXI_DB_EXPORT TQDomElement saveBooleanElementToDom(TQDomDocument& doc, TQDomElement& parentEl,
const TQString& elementName, bool value);
/*! \return an empty value that can be set for a database field of type \a type having
diff --git a/kexi/kexidb/lookupfieldschema.h b/kexi/kexidb/lookupfieldschema.h
index 35d3b59fe..a4d6407a6 100644
--- a/kexi/kexidb/lookupfieldschema.h
+++ b/kexi/kexidb/lookupfieldschema.h
@@ -212,8 +212,8 @@ class KEXI_DB_EXPORT LookupFieldSchema
@return a new LookupFieldSchema object even if lookupEl contains no valid contents. */
static LookupFieldSchema* loadFromDom(const TQDomElement& lookupEl);
- /*! Saves data of lookup column schema to \a tqparentEl DOM element of \a doc document. */
- static void saveToDom(LookupFieldSchema& lookupSchema, TQDomDocument& doc, TQDomElement& tqparentEl);
+ /*! Saves data of lookup column schema to \a parentEl DOM element of \a doc document. */
+ static void saveToDom(LookupFieldSchema& lookupSchema, TQDomDocument& doc, TQDomElement& parentEl);
/*! Sets property of name \a propertyName and value \a value for the lookup schema \a lookup
\return true on successful set and false on failure because of invalid value or invalid property name. */